==> satnogs-client-1.0.tar.gz: satnogs-client-1.0/README.md <==
# SatNOGS Client

SatNOGS Ground Station Client software. This package automates the reception of signals from satellites (cubesats, amateur radio satellites, weather satellites) for the satnogs.org network.

## Install and Contribute
To install SatNOGS client, simply:

```
  $ pip install satnogsclient
```

To get the latest development version:

```
  $ git clone https://gitlab.com/librespacefoundation/satnogs/satnogs-client.git
  $ cd satnogs-client
  $ pip install -e .
```

For more information see our [documentation](https://docs.satnogs.org/projects/satnogs-client).

The main repository lives on [Gitlab](https://gitlab.com/librespacefoundation/satnogs/satnogs-client) and all Merge Request should happen there.

## Join

[![irc](https://img.shields.io/badge/Matrix-%23satnogs:matrix.org-blue.svg)](https://riot.im/app/#/room/#satnogs:matrix.org)
[![irc](https://img.shields.io/badge/IRC-%23satnogs%20on%20freenode-blue.svg)](https://webchat.freenode.net/?channels=satnogs)
[![irc](https://img.shields.io/badge/forum-discourse-blue.svg)](https://community.libre.space/c/satnogs)

## Current Development

[![build](https://gitlab.com/librespacefoundation/satnogs/satnogs-client/badges/master/build.svg)](https://gitlab.com/librespacefoundation/satnogs/satnogs-client/commits/master)

## License

[![license](https://img.shields.io/badge/license-AGPL%203.0-6672D8.svg)](LICENSE)
[![Libre Space Foundation](https://img.shields.io/badge/%C2%A9%202014--2018-Libre%20Space%20Foundation-6672D8.svg)](https://librespacefoundation.org/)

==> satnogs-client-1.3.1.tar.gz: satnogs-client-1.3.1/README.md <==
# SatNOGS Client

SatNOGS Ground Station Client software.
This package automates the reception of signals from satellites (cubesats, amateur radio satellites, weather satellites) for the satnogs.org network.


## Dependencies

SatNOGS client depends on `libhamlib2` Python bindings.


## Install and Contribute

To install SatNOGS client, simply:

```
  $ pip install satnogs-client
```

To get the latest development version:

```
  $ git clone https://gitlab.com/librespacefoundation/satnogs/satnogs-client.git
  $ cd satnogs-client
  $ pip install -e .
```

For more information see our [documentation](https://docs.satnogs.org/projects/satnogs-client).

The main repository lives on [Gitlab](https://gitlab.com/librespacefoundation/satnogs/satnogs-client) and all Merge Request should happen there.


## Join

[![irc](https://img.shields.io/badge/Matrix-%23satnogs:matrix.org-blue.svg)](https://riot.im/app/#/room/#satnogs:matrix.org)
[![irc](https://img.shields.io/badge/IRC-%23satnogs%20on%20freenode-blue.svg)](https://webchat.freenode.net/?channels=satnogs)
[![irc](https://img.shields.io/badge/forum-discourse-blue.svg)](https://community.libre.space/c/satnogs)


## Current Development

[![build](https://gitlab.com/librespacefoundation/satnogs/satnogs-client/badges/master/build.svg)](https://gitlab.com/librespacefoundation/satnogs/satnogs-client/commits/master)


## License

[![license](https://img.shields.io/badge/license-AGPL%203.0-6672D8.svg)](LICENSE)
[![Libre Space Foundation](https://img.shields.io/badge/%C2%A9%202014--2020-Libre%20Space%20Foundation-6672D8.svg)](https://librespacefoundation.org/)
